/**
 * 企业经营数据
 */

import {Schema} from 'mongoose';
import { baseDB } from '../../db/mongo/dbInit';

const businessSchema = new Schema({
    year:{type:Number, index:true},//年度
    quarters:{type:Number, index:true},//季度
    uscc:{type:String, index:true},
    BI:Number,//营业收入
    RD:Number,//研发投入
    TXP:Number,//纳税
    createTime:Number,//填写时间
    isSubmit:{type:Boolean, default:false},//是否提交
    // isReplenish:{type:Boolean, default:false},//是否补充数据
});

var businessDataModel;
export function initModel(){
    businessDataModel = baseDB.model('business', businessSchema);
    businessDataModel.selectOnceData = async function (paramater:object) {
        let selectInfo = await businessDataModel.findOne(paramater).exec();
        if (selectInfo) {
            if (!selectInfo.runSave) {
                selectInfo.runSave = selectInfo.save;
                selectInfo.save = save.bind(selectInfo)
            }
        }
        return selectInfo;
    }
}
export async function save(throwError=false) {
    if (!this.isModified()) return;
    await this.runSave({validateBeforeSave:false}).catch(err=>{
        console.log(err);
    });
}


/**
 * 获取特定企业某年度的经营数据
 * @param uscc 企业统一信用代码
 * @param year 年度
 */
export async function findBusinessDataByUsccAndYear(uscc:string, year:number) {
    return await businessDataModel.find({uscc, year});
    
}

export async function findBusinessDataByTimeAndUscc(uscc:string, year:number, quarters:number) {
    return await businessDataModel.selectOnceData({uscc, year, quarters});
}

export async function findNotSubmitBusinessDataByTimeAndUscc(uscc:string, year:number, quarters:number) {
    return await businessDataModel.selectOnceData({uscc, year, quarters, isSubmit:false});
}



export async function createBusinessData(uscc:string, year:number, quarters:number, BI:number, RD:number, TXP:number ) {
    let addInfo = {uscc, year, quarters, BI, RD, TXP, createTime:new Date().valueOf() };
    await businessDataModel.create(addInfo);
}
